import { VideoPlaylistPrivacy, VideoPrivacy } from '@peertube/peertube-models';
import { getAPPublicValue } from '../../helpers/activity-pub-utils.js';
export function getPublicAudience(actorSender) {
    return buildAudience([actorSender.followersUrl], 'public');
}
export function getVideoAudience(actorSender, privacy, options = {}) {
    const { skipPrivacyCheck = false } = options;
    const followerUrls = [actorSender.followersUrl];
    if (privacy === VideoPrivacy.PUBLIC)
        return buildAudience(followerUrls, 'public');
    else if (privacy === VideoPrivacy.UNLISTED)
        return buildAudience(followerUrls, 'unlisted');
    if (skipPrivacyCheck)
        return buildAudience(followerUrls, 'private');
    throw new Error(`Cannot get audience of non public/unlisted video privacy type (${privacy})`);
}
export function getPlaylistAudience(actorSender, privacy) {
    const followerUrls = [actorSender.followersUrl];
    if (privacy === VideoPlaylistPrivacy.PUBLIC)
        return buildAudience(followerUrls, 'public');
    else if (privacy === VideoPlaylistPrivacy.UNLISTED)
        return buildAudience(followerUrls, 'unlisted');
    throw new Error(`Cannot get audience of non public/unlisted playlist privacy type (${privacy})`);
}
export function audiencify(object, audience) {
    return Object.assign(Object.assign({}, audience), object);
}
function buildAudience(followerUrls, type) {
    let to = [];
    let cc = [];
    if (type === 'public') {
        to = [getAPPublicValue()];
        cc = followerUrls;
    }
    else if (type === 'unlisted') {
        to = [];
        cc = [getAPPublicValue()];
    }
    else {
        to = [];
        cc = [];
    }
    return { to, cc };
}
//# sourceMappingURL=audience.js.map